@@ -6,7 +6,7 @@ with 'Dist::Zilla::Role::PluginBundle::Easy',
   'Dist::Zilla::Role::PluginBundle::PluginRemover';
 use namespace::clean;
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 # Revisions can include entries with the standard plugin name, array ref of plugin/name/config,
 # or coderefs which are passed the pluginbundle object and return one of these formats.
@@ -107,11 +107,19 @@ uploading to CPAN.
 
   $ FAKE_RELEASE=1 dzil release
 
+Migrating from C<[@Basic]> is easy for most cases. Most of the bundle is the
+same, so just make sure to remove any extra plugins that C<[@Starter]> already
+includes. Migrating a more complex set of plugins, including some that interact
+with the additional generated files, may require more careful consideration.
+
+For one-line initialization of a new C<[@Starter]>-based distribution, try
+L<Dist::Zilla::MintingProfile::Starter>.
+
 =head1 REVISIONS
 
 The C<[@Starter]> plugin bundle currently includes only one revision.
 
-=head2 1
+=head2 Revision 1
 
 Revision 1 is the default and is equivalent to using the following plugins:
 
@@ -311,4 +319,5 @@ This is free software, licensed under:
 
 =head1 SEE ALSO
 
-L<Dist::Zilla>, L<Dist::Zilla::PluginBundle::Basic>
+L<Dist::Zilla>, L<Dist::Zilla::PluginBundle::Basic>,
+L<Dist::Zilla::MintingProfile::Starter>
